const winston = require('winston');
require('winston-daily-rotate-file')
const config = require('config');

/**
 * Custom format.
 */
const dstAppFormat = winston.format.printf(({ level, message, timestamp }) => {
    return `${timestamp} [${level}]: ${message}`;
});

/**
 * Logger rotation configuration.
 * @type {DailyRotateFile}
 */
const rotate = new winston.transports.DailyRotateFile({
    filename: 'application-%DATE%.log',
    datePattern: 'YYYY-MM-DD-HH',
    zippedArchive: true,
    maxSize: '1m',
    maxFiles: '30d'
});

/**
 * Initializing winston logger.
 * @type {winston.Logger}
 */
const logger = winston.createLogger({
    level: config.get('logging.level'),
    silent: config.get('logging.silent'),
    format: winston.format.combine(
        winston.format.splat(),
        winston.format.timestamp(),
        dstAppFormat
    ),
    transports: [
        new winston.transports.Console({
            level: config.get('logging.console.level'),
            silent: config.get('logging.console.silent'),
            format: winston.format.combine(
                winston.format.colorize(),
                winston.format.splat(),
                winston.format.timestamp(),
                dstAppFormat
            )
        }),
        rotate
    ],
    exitOnError: false
});

/**
 * Exporting created logger.
 * @type {{log: exports.log}}
 */
module.exports = logger;
